@@ -192,8 +192,8 @@ empty_loanbook_tibble <- function(loanbook, old_groups) {
 
 expand_alias <- function(loanbook, ald) {
   vars <- c("sector", "alias")
-  l <- dplyr::nest_by(select(loanbook, vars), .data$sector, .key = "alias_lbk")
-  a <- dplyr::nest_by(select(ald, vars), .data$sector, .key = "alias_ald")
+  l <- nest_by(select(loanbook, vars), .data$sector, .key = "alias_lbk")
+  a <- nest_by(select(ald, vars), .data$sector, .key = "alias_ald")
   la <- dplyr::inner_join(l, a, by = "sector")
 
   purrr::map2_df(
@@ -202,6 +202,13 @@ expand_alias <- function(loanbook, ald) {
   )
 }
 
+# Similar to nest_by() from dplyr >= 1.0.0, but works with dplyr >= 0.8.5
+nest_by <- function(.data, ..., .key = "data") {
+  grouped <- dplyr::group_by(.data, ...)
+  nested <- tidyr::nest(grouped)
+  dplyr::rename(nested, !!.key := .data$data)
+}
+
 unsuffix_and_regroup <- function(data, old_groups) {
   data %>%
     rename(alias = .data$alias_lbk) %>%
