@@ -461,7 +461,7 @@ test_that("0-row output has expected column type", {
 })
 
 test_that("works with UP266", {
-  skip("FIXME: Should fail with `rhub::check(platform = 'ubuntu-gcc-release')")
+  skip_if(on_platform_that_fails_misteriously(), "We don't bother testing")
 
   up266 <- filter(loanbook_demo, id_ultimate_parent == "UP266")
   out <- match_name(up266, ald_demo)
@@ -476,7 +476,8 @@ test_that("works with UP266", {
 })
 
 test_that("with loanbook_demo and ald_demo outputs known output", {
-  skip("FIXME: This fails `rhub::check(platform = 'ubuntu-gcc-release')")
+  skip_if(on_platform_that_fails_misteriously(), "We don't bother testing")
+
   out <- match_name(loanbook_demo, ald_demo)
   expect_known_value(out, "ref-match-name", update = FALSE)
 
